mirror of
https://github.com/MartinOpat/cuda-based-raytrace.git
synced 2025-06-07 02:13:10 +02:00
Merge branch 'finding-sany2' into gui
This commit is contained in:
11
src/consts.h
11
src/consts.h
@@ -41,8 +41,8 @@ const float stepSize = 0.02f;
|
||||
// Shading consts
|
||||
const double ambientStrength = 0.3;
|
||||
const double diffuseStrength = 0.8;
|
||||
const double specularStrength = 0.5;
|
||||
const int shininess = 32;
|
||||
extern __device__ double d_specularStrength; // = 0.5;
|
||||
extern __device__ int d_shininess; // = 32;
|
||||
const float fov = 60.0f * (M_PI / 180.0f);
|
||||
|
||||
// Camera and Light
|
||||
@@ -78,11 +78,14 @@ extern __device__ int d_samplesPerPixel;
|
||||
// Silhouettes
|
||||
extern __device__ bool d_showSilhouettes;
|
||||
extern __device__ float d_silhouettesThreshold;
|
||||
// controlling levoy opacity function
|
||||
extern __device__ float d_levoyFocus;
|
||||
extern __device__ float d_levoyWidth;
|
||||
|
||||
const int lenStopsPythonLike = 11;
|
||||
const int lenStopsPythonLike = 5;
|
||||
const int lenStopsGrayscale = 2;
|
||||
const int lenStopsBluePurpleRed = 3;
|
||||
extern __constant__ ColorStop d_stopsPythonLike[11];
|
||||
extern __constant__ ColorStop d_stopsPythonLike[5];
|
||||
extern __constant__ ColorStop d_stopsGrayscale[2];
|
||||
extern __constant__ ColorStop d_stopsBluePurleRed[3];
|
||||
|
||||
|
||||
Reference in New Issue
Block a user